==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/action.defaultadmin.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

if( $this->CheckPermission('Modify Templates') ||
    $this->CheckPermission('Modify Site Preferences') )
  {
    echo '<div class="pageoverflow" style="text-align: right; width: 80%;">';
    if( $this->CheckPermission('Modify Site Preferences') ) {
      echo $this->CreateImageLink($id,'admin_settings',$returnid,
				  $this->Lang('lbl_settings'),
				  'icons/topfiles/preferences.gif',array(),'','',false);
    }
    if( $this->CheckPermission('Modify Templates') ) {
      echo $this->CreateImageLink($id,'admin_templates',$returnid,
				  $this->Lang('lbl_templates'),
				  'icons/topfiles/template.gif',array(),'','',false);
    }
    echo '</div>';
  }

echo $this->StartTabHeaders();
if( $this->CheckPermission(CGSocialApp::PERMISSION) ) {
  echo $this->SetTabHeader('keys',$this->Lang('tab_apikeys'));
  echo $this->SetTabHeader('activities',$this->Lang('tab_activities'));
  echo $this->SetTabHeader('leaderboards',$this->Lang('leaderboards'));
 }
echo $this->EndTabHeaders();

echo $this->StartTabContent();
if( $this->CheckPermission(CGSocialApp::PERMISSION) ) {
  echo $this->StartTab('keys',$params);
  include(dirname(__FILE__).'/function.admin_keys_tab.php');
  echo $this->EndTab();
 }
if( $this->CheckPermission('Modify Site Preferences') ) {
  echo $this->StartTab('activities',$params);
  include(dirname(__FILE__).'/function.admin_activities_tab.php');
  echo $this->EndTab();
  
  echo $this->StartTab('leaderboards',$params);
  include(dirname(__FILE__).'/function.admin_leaderboards_tab.php');
  echo $this->EndTab();
 }
echo $this->EndTabContent();

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/action.defaultadmin.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

if( $this->CheckPermission('Modify Templates') ||
    $this->CheckPermission('Modify Site Preferences') )
  {
    echo '<div class="pageoverflow" style="text-align: right; width: 80%;">';
    if( $this->CheckPermission('Modify Site Preferences') ) {
      echo $this->CreateImageLink($id,'admin_settings',$returnid,
				  $this->Lang('lbl_settings'),
				  'icons/topfiles/preferences.gif',array(),'','',false);
    }
    if( $this->CheckPermission('Modify Templates') ) {
      echo $this->CreateImageLink($id,'admin_templates',$returnid,
				  $this->Lang('lbl_templates'),
				  'icons/topfiles/template.gif',array(),'','',false);
    }
    echo '</div>';
  }

echo $this->StartTabHeaders();
if( $this->CheckPermission(CGSocialApp::PERMISSION) ) {
  echo $this->SetTabHeader('keys',$this->Lang('tab_apikeys'));
  echo $this->SetTabHeader('activities',$this->Lang('tab_activities'));
  echo $this->SetTabHeader('leaderboards',$this->Lang('leaderboards'));
}
if( $this->CheckPermission(CGSocialApp::PERMISSION_CHECKINS) ) {
  echo $this->SetTabHeader('checkins',$this->Lang('tab_checkins'));
}
echo $this->EndTabHeaders();

echo $this->StartTabContent();
if( $this->CheckPermission(CGSocialApp::PERMISSION) ) {
  echo $this->StartTab('keys',$params);
  include(__DIR__.'/function.admin_keys_tab.php');
  echo $this->EndTab();
}
if( $this->CheckPermission(CGSocialApp::PERMISSION_CHECKINS) ) {
  echo $this->StartTab('checkins',$params);
  include(__DIR__.'/function.admin_checkins_tab.php');
  echo $this->EndTab();
}
if( $this->CheckPermission('Modify Site Preferences') ) {
  echo $this->StartTab('activities',$params);
  include(__DIR__.'/function.admin_activities_tab.php');
  echo $this->EndTab();
  
  echo $this->StartTab('leaderboards',$params);
  include(__DIR__.'/function.admin_leaderboards_tab.php');
  echo $this->EndTab();
}
echo $this->EndTabContent();

#
# EOF
#
?>
